@@ -14,46 +14,28 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import os
-import urllib2
-import urlparse
-import base64
-import logging
-import ConfigParser
-import json
+""" Support methods for verifying iOS builds
+"""
+
 import sys
 import string
-import re
 import textwrap
 import subprocess
 import plistlib
+import os
+import re
+import support
 
 from collections import namedtuple
 from xml.parsers.expat import ExpatError
-from datetime import datetime
-
 
+# AirshipConfig.plist keys
 APP_STORE_OR_AD_HOC = "APP_STORE_OR_AD_HOC_BUILD"
 DEVELOPMENT_APP_KEY = "DEVELOPMENT_APP_KEY"
 DEVELOPMENT_APP_SECRET = "DEVELOPMENT_APP_SECRET"
 PRODUCTION_APP_SECRET = "PRODUCTION_APP_SECRET"
 PRODUCTION_APP_KEY = "PRODUCTION_APP_KEY"
 
-# Configuration values
-DEFAULT_CONFIG_NAME = "ua_inspection.cfg"
-UA_SECTION = "ua_config"
-LOG_LEVEL = "log_level"
-ENTITLEMENTS_PLIST_PATH = "entitlement_plist_path"
-AIRSHIP_CONFIG_PLIST = "airship_config_plist"
-
-# UA API URLS
-UA_API_BASE = "api_base"
-UA_API_PATH = "api_path"
-
-# Exit status
-EXIT_SUCCESS = 0
-EXIT_FAILURE = 1
-
 # API JSON Response Keys, currently the API call returns the bundle id and
 # a boolean indicating whether or not th app is in production
 UA_API_RESPONSE_BUNDLE_ID_KEY = "bundle_id"
@@ -70,144 +52,23 @@ DEPRECATED_PLIST_PATH = "/tmp/ConvertedAirshipConfig.plist"
 PRODUCTION_SERVER = "production"
 DEVELOPMENT_SERVER = "development"
 
+#setup logging
+log = support.log
 
 
-# Configuration parsing
-# Load configuration file, or log an error
-_config_parser = ConfigParser.ConfigParser()
-_config_path = os.path.dirname(os.path.abspath(__file__))
-_config_path = os.path.join(_config_path, DEFAULT_CONFIG_NAME)
-
-if not os.path.exists(_config_path):
-    logging.error("No config file found at path %s", _config_path)
-    sys.exit(EXIT_FAILURE)
-
-_config_parser.read(_config_path)
-
-# Log wrappers
-OKGREEN = '\033[92m'
-WARNING = '\033[93m'
-FAIL = '\033[91m'
-ENDC = '\033[0m'
-
-# Log messages and flair settings
-PIECES_OF_FLAIR = 37
-def flair(flair_char, flair_amount=PIECES_OF_FLAIR):
-    """Pick the flair. You do want to express yourself, don't your?
-
-    :param flair_char: Character to use as flair wrapper
-    :type key: str
-    :param flair_amount: Amount of flair. Must be greater than bare minimum
-    :type key: int
-    """
-
-    all_the_flair = ''
-    if flair_amount < 37:
-        flair_amount = 37
-        print("Do you want to do the bare minimum?")
-
-    for i in range(flair_amount):
-        all_the_flair += flair_char
-    return all_the_flair
-
-# Flair characters
-_pass_flair = flair('#')
-_fail_flair = flair('*')
-_warn_flair = flair('!')
-
-# Log a message indicating a passing test
-def pass_log_message(msg):
-    """Print a log message wrapped in pass flair (green colored characters)
-
-    Color output requires ANSI console colors
-    :param msg: Message to wrap in green output
-    :type key: str
-    """
-    print OKGREEN + '\n'+ _pass_flair + "\nPASS:" + ENDC
-    print(msg)
-    print OKGREEN + _pass_flair + '\n' + ENDC
-
-def warn_log_message(msg):
-    """Print a log message wrapped in warn flair (yellow colored characters)
-
-    Color output requires ANSI console colors
-    :param msg: Message to wrap in yellow output
-    :type key: str
-    """
-    print WARNING + '\n' + _warn_flair + "\nWARNING" + ENDC
-    print(msg)
-    print WARNING + '\n' + _warn_flair + "\n" + ENDC
-
-
-# Print a log message surrounded by red fail flair, indicating flairlure
-def fail_log_message(msg, remedial_action):
-    """Print a log message wrapped in red flair, indicating failure
-
-    :param msg: Message describing failure
-    :type key: str
-    :param remedial_action: Message describing steps that can be taken to
-    fix the issue described in the error message
-
-    :type key: str
-    """
-
-    print FAIL + _fail_flair + "\nFAIL:" + ENDC
-    log.info(msg + "\n" + remedial_action)
-    print FAIL + _fail_flair + ENDC
-
 def clean():
     """ Cleanup any previous build cruft
 
     Currently only erases previous entitlement plists
     """
-    entitlement_plist_path = get_value_from_config(ENTITLEMENTS_PLIST_PATH)
+    entitlement_plist_path = support.get_value_from_config(
+        support.ENTITLEMENTS_PLIST_PATH)
 
     if os.path.exists(entitlement_plist_path):
         log.info("Removing old entitlements plist file at %s",
             entitlement_plist_path)
         os.remove(entitlement_plist_path)
 
-def get_value_from_config(key, section=UA_SECTION):
-    """Returns a configuration value for the given key.
-
-    Return the value associated with the key
-    from the configuration file. Uses the default
-    section defined by UA_SECTION unless overridden
-    See ConfigParser for more details
-
-    :param key: Key associated with value
-    :type key: str
-    :param section: Section to retrieve value from
-    :type section: str
-    """
-
-    return _config_parser.get(section, key)
-
-# Logging setup
-# Timestamp and log formatting
-# LogLevel
-log_format = '%(asctime)s:%(levelname)s %(message)s'
-logging.basicConfig(format=log_format)
-log = logging.getLogger(name=__name__)
-log.setLevel(get_value_from_config(LOG_LEVEL))
-
-def setup_diagnostic_logging():
-    """Adds a file handler to the logger object to output information
-
-    Also attempts to prepend the diagnostic log file with entitlement and
-    configuration information
-    """
-
-    log.setLevel(logging.DEBUG)
-    now = datetime.now()
-    filename = now.strftime("ua_verify_diagnostic_%d%b%y_%H%M%S.txt")
-
-    path = os.getcwd()
-    file_path = os.path.join(path, filename)
-    log.info("Diagnostic log path %s", file_path)
-    log_handler = logging.FileHandler(file_path)
-    log_handler.setLevel(logging.DEBUG)
-    log.addHandler(log_handler)
 
 # API methods
 
@@ -220,56 +81,7 @@ APP_KEY_SECRET_INCORRECT_403 = """
 The wrong value is being used for the app secret. This is the master secret,
 and is used for API communication outside of the scope of a client app. It
 should never be used in an app, or placed in an app bundle, as that would
-be a security risk"""
-
-# Store the API response to use in diagnostic print outs
-_ua_api_response = None
-
-def make_request_against_api(request):
-    """Make a request against the UA API
-
-    Returns a named tuple with response data as JSON and a possible error
-    object which is either an HTTPError, 401,500, etc or a URLError which
-    most likely occurs when there is no connection. All other errors will
-    exception out.
-
-    :param request: Request to make
-    :type key: urllib2.Request
-    :return: Named tuple in the form (response, error)
-    :rtype: namedtuple
-    """
-
-    error = None
-    json_data = None
-    Response = namedtuple('Response', ["json", "error"])
-
-    try:
-        raw_response = urllib2.urlopen(request)
-        json_data = json.load(raw_response)
-
-    except urllib2.HTTPError as http_error:
-        log.error("HTTP error %s with code %d", http_error.message,
-            http_error.code)
-        error = http_error
-
-        if error.code == 401:
-            fail_log_message("Incorrect app key and secret",
-            APP_KEY_SECRET_INCORRECT_401)
-
-        if error.code == 403:
-            fail_log_message("Incorrect app secret",
-                APP_KEY_SECRET_INCORRECT_403)
-
-    except urllib2.URLError as url_error:
-        log.error("URL error, are you connected to the internet?")
-        log.error("URL error message %s", url_error)
-        error = url_error
-        fail_log_message("No internet connection",
-            "Connect to internet, rerun script")
-
-    response = Response(json=json_data, error=error)
-    _ua_api_response = response
-    return response
+be a security risk. Please review your app settings"""
 
 
 def get_verification_request(ua_verification_information):
@@ -286,17 +98,35 @@ def get_verification_request(ua_verification_information):
     :return: Pre authenticated http request
     :rtype: urllib2.Request
     """
-
-    base_url = get_value_from_config(UA_API_BASE)
-    api_url = get_value_from_config(UA_API_PATH)
-    ua_url = urlparse.urljoin(base_url, api_url)
-    log.info("URL for verification call %s", ua_url)
     key, secret = ua_verification_information.key_secret()
-    basic_auth = "{0}:{1}".format(key, secret)
-    basic_auth_encoded = base64.encodestring(basic_auth)
-    pre_auth = {'Authorization': "Basic %s" % basic_auth_encoded}
-    log.debug("Headers for UA verification request %s", pre_auth)
-    return urllib2.Request(ua_url, headers=pre_auth)
+    return support.get_base_verification_request(appKey=key, appSecret=secret)
+
+def make_request_against_api(request):
+    """Make a request against the UA API
+
+    Returns a named tuple with response data as JSON and a possible error
+    object which is either an HTTPError, 401,500, etc or a URLError which
+    most likely occurs when there is no connection. All other errors will
+    exception out. Will display the proper
+
+    :param request: Request to make
+    :type key: urllib2.Request
+    :return: Named tuple in the form (response, error)
+    :rtype: namedtuple
+    """
+
+    response = support.make_request_against_api(request)
+
+    if response.error is not None:
+
+        if response.error.code == 401:
+            support.fail_log_message("Incorrect app key and secret",
+                APP_KEY_SECRET_INCORRECT_401)
+
+        if response.error.code == 403:
+            support.fail_log_message("Incorrect app secret",
+                APP_KEY_SECRET_INCORRECT_403)
+    return response
 
 
 def extract_airship_config_from_app(application_path):
@@ -310,7 +140,7 @@ def extract_airship_config_from_app(application_path):
     :returns: AirshipConfig.plist as a dictionary
     :rtype: dict
     """
-    airship_config_plist = get_value_from_config(AIRSHIP_CONFIG_PLIST)
+    airship_config_plist = support.get_value_from_config(support.AIRSHIP_CONFIG_PLIST)
     path_to_plist = os.path.join(application_path, airship_config_plist)
 
     try:
@@ -322,12 +152,12 @@ def extract_airship_config_from_app(application_path):
         return None
     # TODO add example about fixing deprecated plist
     except ExpatError:
-        warn_log_message("Plist parsing error, attempting to convert plist")
+        support.warn_log_message("Plist parsing error, attempting to convert plist")
         plist = convert_deprecated_plist_at_path(path_to_plist)
         if plist is None:
             return None
         else:
-            warn_log_message("Plist conversion successful, change to non deprecated "
+            support.warn_log_message("Plist conversion successful, change to non deprecated "
                       "plist format to avoid this error.")
 
     log.debug("AirshipConfig.plist:%s", plist)
@@ -437,7 +267,7 @@ def codesign_system_call_args(path_to_app):
     if path_to_app is None:
         raise TypeError("path_to_app cannot be None")
 
-    plist_path = get_value_from_config(ENTITLEMENTS_PLIST_PATH)
+    plist_path = support.get_value_from_config(support.ENTITLEMENTS_PLIST_PATH)
     # Prepend the path with a colon for the system call
     plist_path = str.format(":{0}", plist_path)
     codesign_call = ["codesign", "-dvvv", "--entitlements", plist_path,
@@ -535,7 +365,7 @@ class VerificationInformation(object):
                     is_production = True
             else:
                 # If not a bool or string, quit
-                fail_log_message("AirshipConfig.plist not readable",
+                support.fail_log_message("AirshipConfig.plist not readable",
                     AIRSHIP_CONFIG_PARSE_FAIL)
                 sys.exit(EXIT_FAILURE)
         return is_production
@@ -580,7 +410,7 @@ class VerificationInformation(object):
             full_bundle_id = self.entitlements_plist[ENTITLE_APP_ID_KEY]
         except KeyError:
             # TODO better error message
-            fail_log_message("""Entitlements plist does not have a app id, this
+            support.fail_log_message("""Entitlements plist does not have a app id, this
             might be a bug in the script.""",
                 """Email support@urbanairship.com""")
             return False
@@ -590,11 +420,11 @@ class VerificationInformation(object):
             msg = "No APS environment key"
             remedial = APS_ENVIRONMENT_KEY_FAIL.format(
                 bundle_id=full_bundle_id)
-            fail_log_message(msg, remedial)
+            support.fail_log_message(msg, remedial)
             return False
-        msg = "Environment is set properly for bundle id{0}".format(
+        msg = "Environment is set properly for bundle id {0}".format(
             full_bundle_id)
-        pass_log_message(msg)
+        support.pass_log_message(msg)
         return True
 
 
@@ -616,8 +446,6 @@ class VerificationInformation(object):
         :rtype: bool
         """
 
-
-
         adhoc_or_prod = self.airship_config_is_production()
 
         if adhoc_or_prod:
@@ -645,13 +473,13 @@ class VerificationInformation(object):
                 aps_environment, ua_aps_configuration, app_key=app_key,
                 app_secret=app_secret, ua_server=ua_aps_configuration,
                 entitle_server=aps_env_description)
-            fail_log_message(msg, remedial)
+            support.fail_log_message(msg, remedial)
             return False
         msg = "\nUrban Airship server is configured for: {0}\n".format(
             ua_aps_configuration)
 
         msg += "App is configured for: {0}".format(aps_environment)
-        pass_log_message(msg)
+        support.pass_log_message(msg)
         return True
 
     def check_bundle_id(self, ua_verification_response):
@@ -678,12 +506,12 @@ class VerificationInformation(object):
         log.info("Urban Airship Configured App Bundle id is: %s", ua_bundle_id)
 
         if entitlements_bundle_id == ua_bundle_id:
-            pass_log_message("Bundle id is correct")
+            support.pass_log_message("Bundle id is correct")
             return True
         else:
            remedial = CHECK_BUNDLE_ID_FAIL.format(
                app_bundle=entitlements_bundle_id, ua_bundle=ua_bundle_id)
-           fail_log_message("Bundle id is incorrect", remedial)
+           support.fail_log_message("Bundle id is incorrect", remedial)
            return False
 
     def log_diagnostic_information(self):
@@ -692,4 +520,4 @@ class VerificationInformation(object):
 
         log.debug("ENTITLEMENTS:\n%s", self.entitlements_plist)
         log.debug("AIRSHIP_CONFIG:\n%s", self.airship_config_plist)
-        log.debug("UA_API_RESPONSE:\n%s", _ua_api_response)
+        log.debug("UA_API_RESPONSE:\n%s", support._ua_api_response)
